@@ -6,7 +6,7 @@ use 5.008_001;
 use Getopt::Long qw/GetOptionsFromArray/;
 use constant DEFAULT_CONFIG => (no_auto_abbrev => 1, bundling => 1);
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub new {
     my ($class, %args) = @_;
@@ -89,21 +89,32 @@ sub opts {
 }
 
 sub usage {
-    my($self, $command) = @_;
+    my($self, @targets) = @_;
     my $usage = "";
     my(@help, @commands);
 
-    if ((defined $self->command && $self->command eq 'help') || defined $command) {
+    if ((defined $self->command && $self->command eq 'help') || @targets) {
         delete $self->{command};
-        my $target;
-        if (defined($target = $self->{_argv}[0]) || defined($target = $command)) {
+        @targets = @{$self->{_argv}} unless @targets;
+        for (my $i = 0; $i < @targets; $i++) {
+            my $target = $targets[$i];
+            last unless defined $target;
             unless (ref $self->{_struct}{$target} eq 'HASH') {
                 $self->{error} = "Unknown command: $target";
+                last;
             }
             else {
                 $self->{command} = $target;
+                push @{$self->{commands}}, $target;
                 $self->_init_struct($self->{_struct}{$target}{options});
                 $self->_extends_usage($self->{_struct}{$target});
+
+                if (ref $self->{_struct}{$target}{command_struct} eq 'HASH') {
+                    $self->{_struct} = $self->{_struct}{$target}{command_struct};
+                }
+                else {
+                    $self->{summary} = {};
+                }
             }
         }
     }
@@ -609,6 +620,29 @@ Gets sub-command name.
   $ ./foo.pl bar
   bar
 
+=head2 commands
+
+Get sub commands. Returned value is ARRAYREF.
+
+  # inside foo.pl
+  use Getopt::Compact::WithCmd;
+  
+  my $go = Getopt::Compact::WithCmd->new(
+     command_struct => {
+        bar => {
+            command_struct => {
+                baz => {},
+            },
+        },
+     },
+  );
+  
+  print join(", ", @{$go->commands}), "\n";
+  
+  # running the command
+  $ ./foo.pl bar baz
+  bar, baz
+
 =head2 status
 
 This is a true value if the command line was processed successfully. Otherwise it returns a false result.
